/* @(#) $Id: xwd.h 345 2023-10-10 19:56:04Z leres $ (XSE) */
#ifndef xwd_h
#define xwd_h

struct xwdheader {
	int s;					/* header size in bytes */
	int v;					/* version */
	union {
		struct {
			int x[5];
			int w;			/* width */
			int h;			/* height */
			/* ... */
		} x10;
		struct {
			int x[18];
			int w;			/* width */
			int h;			/* height */
			/* ... */
		} x11;
	}u;
};

#define XWD_VX10 6
#define XWD_VX11 7

extern int parsexwd(const char *, int *, int *, struct timespec *);
extern int bs32(int);
#endif
